package fr.enssat.BoulderDash.controllers;

import fr.enssat.BoulderDash.models.DisplayableElementModel;
import fr.enssat.BoulderDash.models.LevelModel;

import java.awt.event.KeyEvent;


/**
 * GameKeyController
 * <p>
 * Manages the key events controller.
 *
 * @author Colin Leverger <me@colinleverger.fr>
 * @since 2015-06-19
 */
public class GameKeyController extends AbstractKeyController {
  private RockfordUpdateController updatePosRockford;

  /**
   * Class constructor
   *
   * @param levelModel Level model
   */
  public GameKeyController(LevelModel levelModel) {
    super(levelModel);
    new BoulderAndDiamondController(levelModel);
    this.updatePosRockford = new RockfordUpdateController(levelModel);
  }

  @Override
  protected void up() {
    DisplayableElementModel upElement = levelModel.getGroundLevelModel()[levelModel.getRockfordPositionX()][levelModel.getRockfordPositionY() - 1];

    if (upElement.getPriority() < levelModel.getRockford().getPriority()) {
      this.updatePosRockford.moveRockford(levelModel.getRockfordPositionX(), levelModel.getRockfordPositionY() - 1);
      this.levelModel.getRockford().startRunningUp();
    }
  }

  @Override
  protected void down() {
    DisplayableElementModel downElement = levelModel.getGroundLevelModel()[levelModel.getRockfordPositionX()][levelModel.getRockfordPositionY() + 1];

    if (downElement.getPriority() < levelModel.getRockford().getPriority()) {
      this.updatePosRockford.moveRockford(levelModel.getRockfordPositionX(), levelModel.getRockfordPositionY() + 1);
      this.levelModel.getRockford().startRunningDown();
    }
  }

  @Override
  protected void left() {
    DisplayableElementModel leftElement = levelModel.getGroundLevelModel()[levelModel.getRockfordPositionX() - 1][levelModel.getRockfordPositionY()];

    if (leftElement.getPriority() < levelModel.getRockford().getPriority()) {
      this.updatePosRockford.moveRockford(levelModel.getRockfordPositionX() - 1, levelModel.getRockfordPositionY());
      this.levelModel.getRockford().startRunningLeft();
    }
  }

  @Override
  protected void right() {
    DisplayableElementModel rightElement = levelModel.getGroundLevelModel()[levelModel.getRockfordPositionX() + 1][levelModel.getRockfordPositionY()];

    if (rightElement.getPriority() < levelModel.getRockford().getPriority()) {
      this.updatePosRockford.moveRockford(levelModel.getRockfordPositionX() + 1, levelModel.getRockfordPositionY());
      this.levelModel.getRockford().startRunningRight();
    }
  }

  /**
   * Handles the 'key released' event
   *
   * @param e Key event
   */
  @Override
  public void keyReleased(KeyEvent e) {
    this.levelModel.getRockford().startStaying();
  }
}
