package fr.enssat.BoulderDash.controllers;

import fr.enssat.BoulderDash.models.LevelModel;
import fr.enssat.BoulderDash.views.LevelEditorView;


/**
 * LevelEditorKeyController
 * <p>
 * Manages the key events controller.
 *
 * @author Valerian Saliou <valerian@valeriansaliou.name>
 * @since 2015-06-21
 */
public class LevelEditorKeyController extends AbstractKeyController {
  private LevelEditorView levelEditorView;
  private boolean capLocks;

  /**
   * Class constructor
   *
   * @param levelModel      Level model
   * @param levelEditorView Level editor view
   */
  public LevelEditorKeyController(LevelModel levelModel, LevelEditorView levelEditorView) {
    super(levelModel);
    this.capLocks = false;
    this.levelEditorView = levelEditorView;
  }

  @Override
  protected void additionalSteps() {
    // Hold block change (quick edit)
    if (capLocks) {
      this.levelModel.triggerBlockChange(this.levelEditorView.getPickedBlockValue());
    }
  }

  @Override
  protected void up() {
    this.levelModel.decrementCursorYPosition();
    return;
  }

  @Override
  protected void down() {
    this.levelModel.incrementCursorYPosition();
  }

  @Override
  protected void left() {
    this.levelModel.decrementCursorXPosition();
  }

  @Override
  protected void right() {
    this.levelModel.incrementCursorXPosition();
  }

  @Override
  protected void space() {
    this.levelModel.triggerBlockChange(this.levelEditorView.getPickedBlockValue());
  }

  @Override
  protected void shift() {
    this.capLocks = !capLocks;
  }
}
